<?php
/**
 * Created by PhpStorm.
 * User: zain
 * Date: 6/13/2019
 * Time: 8:12 PM
 */

namespace ElementorPtsc;
/**
 * Class Plugin
 *
 * Main Plugin class
 * @since 1.2.0
 */
class Plugin
{
    /**
     * Instance
     *
     * @since 1.2.0
     * @access private
     * @static
     *
     * @var Plugin The single instance of the class.
     */
    private static $_instance = null;

    /**
     * Instance
     *
     * Ensures only one instance of the class is loaded or can be loaded.
     *
     * @return Plugin An instance of the class.
     * @since 1.2.0
     * @access public
     *
     */
    public static function instance()
    {
        if (is_null(self::$_instance)) {
            self::$_instance = new self();
        }
        return self::$_instance;
    }
    /**
     * widget_scripts
     *
     * Load required plugin core files.
     *
     * @since 1.2.0
     * @access public
     */
    /*public function widget_scripts() {
        wp_register_script( 'elementor-ptsc', PTSC_PATH( '/js/elementor-ptsc.js', __FILE__ ), [ 'jquery' ], false, true );
    }*/
    /**
     * Include Widgets files
     *
     * Load widgets files
     *
     * @since 1.2.0
     * @access private
     */
    private function include_widgets_files()
    {
        require_once(__DIR__ . '/widgets/ptsc-currency-combo.php');
        /*
            * Hiding single pricing table on demand, in future,
            * if this is required then just uncomment following code
        */
        /*require_once( __DIR__ . '/widgets/ptsc-pricing-table.php' );*/
        require_once(__DIR__ . '/widgets/group-pricing-table.php');
        require_once(__DIR__ . '/widgets/comparison-table.php');
        require_once(__DIR__ . '/widgets/pricing-slider.php');
        require_once(__DIR__ . '/widgets/ptsc_carousel.php');
        require_once(__DIR__ . '/widgets/ptsc_section.php');
        require_once(__DIR__ . '/widgets/ptsc_tabs.php');
        require_once(__DIR__ . '/widgets/ptsc_client_area.php');
        require_once(__DIR__ . '/widgets/ptsc_jumbotron.php');
        if(get_option('w_mode') == 'display_and_sell') {
            require_once(__DIR__ . '/widgets/makli-order.php');
        }

//        require_once( __DIR__ . '/widgets/inline-editing.php' );
    }

    /**
     * Register Widgets
     *
     * Register new Elementor widgets.
     *
     * @since 1.2.0
     * @access public
     */
    public function register_widgets()
    {
        // Its is now safe to include Widgets files
        $this->include_widgets_files();
        // Register Widgets
        /*
            * Hiding single pricing table on demand, in future,
            * if this is required then just uncomment following code
        */
        /*\Elementor\Plugin::instance()->widgets_manager->register_widget_type(new Widgets\Ptsc_Pricing_Table());*/
        \Elementor\Plugin::instance()->widgets_manager->register_widget_type(new Widgets\Ptsc_Currency_Combo());
        \Elementor\Plugin::instance()->widgets_manager->register_widget_type(new Widgets\Group_Pricing_Table());
        \Elementor\Plugin::instance()->widgets_manager->register_widget_type(new Widgets\Comparison_Table());
        \Elementor\Plugin::instance()->widgets_manager->register_widget_type(new Widgets\Pricing_Slider());
        \Elementor\Plugin::instance()->widgets_manager->register_widget_type(new Widgets\Ptsc_Carousel());
        \Elementor\Plugin::instance()->widgets_manager->register_widget_type(new Widgets\Ptsc_Section());
        \Elementor\Plugin::instance()->widgets_manager->register_widget_type(new Widgets\Ptsc_Tabs());
        \Elementor\Plugin::instance()->widgets_manager->register_widget_type(new Widgets\Ptsc_Client_Area());
        \Elementor\Plugin::instance()->widgets_manager->register_widget_type(new Widgets\Ptsc_Jumbotron());
        if(get_option('w_mode') == 'display_and_sell') {
            \Elementor\Plugin::instance()->widgets_manager->register_widget_type(new Widgets\Makli_Order());
        }

//        \Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Pricing_Table() );
    }

    /**
     *  Plugin class constructor
     *
     * Register plugin action hooks and filters
     *
     * @since 1.2.0
     * @access public
     */
    public function __construct()
    {
        // Register widget scripts
        //add_action( 'elementor/frontend/after_register_scripts', [ $this, 'widget_scripts' ] );
        // Register widgets
        add_action('elementor/widgets/widgets_registered', [$this, 'register_widgets']);

    }
}

// Instantiate Plugin Class
Plugin::instance();