<?php


namespace ElementorPtsc\Widgets;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
Use Elementor\Controls_Stack;

require_once (PTSC_PATH.'/classes/ptsc.php');


class Ptsc_Carousel extends Widget_Base
{
    /**
     * Retrieve the widget name.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name()
    {
        return 'ptsc-carousel';
    }

    /**
     * Retrieve the widget title.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title()
    {
        return __('Makli carousel', 'ptsc');
    }

    /**
     * Retrieve the widget icon.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon()
    {
        return 'eicon-posts-ticker';
    }

    /**
     * Retrieve the list of categories the widget belongs to.
     *
     * Used to determine where to display the widget in the editor.
     *
     * Note that currently Elementor supports only one category.
     * When multiple categories passed, Elementor uses the first one.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return array Widget categories.
     */
    public function get_categories()
    {
        return ['ptsc'];
    }

    /**
     * Retrieve the list of scripts the widget depended on.
     *
     * Used to set scripts dependencies required to run the widget.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return array Widget scripts dependencies.
     */
    public function get_script_depends()
    {
        return ['ptsc'];
    }

    /**
     * Register the widget controls.
     *
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since 1.0.0
     *
     * @access protected
     */
    protected function register_controls()
    {
        $ptsc = new \PTSC();

        //==All shortcode ids
        $result = $ptsc->All_available_group_ids('carousel_table');

        $this->start_controls_section(
            'general',
            [
                'label' => __('General', 'ptsc'),
            ]
        );
        /*$this->add_control(
            'shortcode_vendor',
            [
                'label' => __('To Set Shortcode Options I will use', 'ptsc'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => '',
                'return_value' => 'shortcode_option',
                'options' => [
                    'vc' => __('Visual Editor', 'ptsc'),
                    'shortcode_option' => __('Plugin Options in WP admin',"ptsc"),
                ],
            ]
        );*/

        $this->add_control(
            'gid',
            [
                'label' => __('Select Shortcode Id', 'ptsc'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => '',
                'options' => $result,
                'description' => 'We add shortcodes from wp admin panel, here you can select the shortcode id that you have added there.'
                /*'condition' => [
                    'shortcode_vendor' => 'shortcode_option',

                ],*/
            ]
        );


        $this->end_controls_section();


    }

    /**
     * Render the widget output on the frontend.
     *
     * Written in PHP and used to generate the final HTML.
     *
     * @since 1.0.0
     *
     * @access protected
     */
    protected function render()
    {
        $settings = $this->get_settings_for_display();
        echo '<div class="">';
        //$shortcode_vendor = $settings['shortcode_vendor'];
        $gid = $settings['gid'];

        echo do_shortcode('[makli_carousel gid="' . $gid . '" ]');
        echo '</div>';
    }

    /**
     * Render the widget output in the editor.
     *
     * Written as a Backbone JavaScript template and used to generate the live preview.
     *
     * @since 1.0.0
     *
     * @access protected
     */
    protected function content_template()
    {
        ?>
        <div class="title">
            <!--{{{ settings.shortcode_vendor }}}-->
            {{{ settings.gid }}}
        </div>
        <?php
    }

}