<?php defined( 'ABSPATH' ) or die( "Cannot access pages directly." );
$minimum_required = [
    'wp_multi' => [
        'required' => 'no',
        'recommended' => 'no'
    ],
    'mem_limit' => [
        'required' => 256,
        'recommended' => 512
    ],
    'request_time' => [
        'required' => 1000,
        'recommended' => 500
    ],

    'version_php' => [
        'required' => "7.2",
        'recommended' => "7.2"
    ],
    'version_wp' => [
        'required' => "5.6.1",
        'recommended' => "5.6.1"
    ],

];
//$whmcs_settings = ptsc_get_whmcs_setting();

?>

<div class="wrap ptsc_main ptsc_admin_main">
    <h2 class="wp-heading-inline" style="padding-bottom: 20px"><?php echo esc_html_x('Debug Info', 'admin', 'ptsc') ?></h2>
    <div class="ptsc_panel ptsc_panel_fancy_2 ptsc_panel_primary">
        <div class="ptsc_panel_header">
            <span><?php echo esc_html_x('Debug info to copy and send', 'admin', 'ptsc' ) ?></span>
        </div>
        <div class="ptsc_panel_body" style="background: #f1f1f1">
            <div class="ptsc_selectable_text" id="ptsc_debug_container">
                <div class="ptsc_debug_section ptsc_debug_section_wp">
                    <?php
                    $collapse_class = 'success';

                    // WordPress version
                    $wp_version = get_bloginfo( 'version' );
                    $wp_version_string = '<span class="ptsc_button ptsc_button_small ptsc_button_success">' . $wp_version . '</span>';
                    if (version_compare($wp_version, $minimum_required['version_wp']['required'], 'lt')) {
                        // success
                        $wp_version_string = '<span class="ptsc_button ptsc_button_small ptsc_button_danger">' . $wp_version . '</span>';
                        $wp_version_string .= ' <span class="ptsc_text_danger">' . esc_html__( "WP version should be at least ", "" ) . $minimum_required['version_wp']['required'] . '</span>';
                        $collapse_class = 'danger active';
                    }
                    else if (version_compare($wp_version, $minimum_required['version_wp']['recommended'], 'lt')) {
                        // warning
                        $wp_version_string = '<span class="ptsc_button ptsc_button_small ptsc_button_warning">' . $wp_version . '</span>';
                        $wp_version_string .= ' <span class="ptsc_text_warning">' . esc_html__( "Recommended WP version is ", "" ) . $minimum_required['version_wp']['recommended'] . '</span>';
                        if ($collapse_class != 'danger active') {
                            $collapse_class = 'warning active';
                        }
                    }

                    // Multi site
                    $multi_site             = ( is_multisite() ) ? esc_html__( 'Yes', "ptsc" ) : esc_html__( 'No', "ptsc" );
                    $multi_site_string = '<span class="ptsc_button ptsc_button_small ptsc_button_success">' . $multi_site . '</span>';
                    if ($multi_site == 'Yes') {
                        // success
                        $multi_site_string = '<span class="ptsc_button ptsc_button_small ptsc_button_danger">' . $multi_site . '</span>';
                        $multi_site_string .= ' <span class="ptsc_text_danger">' . esc_html__( "Our plugins are not compatible with Multi-site installs ", "" ) . '</span>';
                        $collapse_class = 'danger active';
                    }

                    // debug mode
                    $debug_mode             = ( defined( 'WP_DEBUG' ) && WP_DEBUG ) ? esc_html__( 'TRUE', "ptsc" ) : esc_html__( 'FALSE', "ptsc" );

                    // max upload size
                    $wp_upload_max          = wp_max_upload_size();
                    $server_upload_max      = intval( str_replace( 'M', '', ini_get( 'upload_max_filesize' ) ) ) * 1024 * 1024;
                    $active_theme = wp_get_theme();
                    if ( $wp_upload_max <= $server_upload_max ) {
                        $max_upload_size = size_format( $wp_upload_max );
                    }
                    else {
                        $max_upload_size = '<span style="color: red;">' . sprintf( __( '%s (The server only allows %s)', "ptsc" ), size_format( $wp_upload_max ), size_format( $server_upload_max ) ) . '</span>';
                    }

                    // WP Memory Limit
                    $wp_mem_limit = WP_MEMORY_LIMIT;
                    $wp_mem_limit_string = '<span class="ptsc_button ptsc_button_small ptsc_button_success">' . $wp_mem_limit . '</span>';
                    if ((float) $wp_mem_limit < $minimum_required['mem_limit']['required']) {
                        // success
                        $wp_mem_limit_string = '<span class="ptsc_button ptsc_button_small ptsc_button_danger">' . $wp_mem_limit . '</span>';
                        $wp_mem_limit_string .= ' <span class="ptsc_text_danger">' . esc_html__( "Minimum Memory limit is ", "ptsc" ) . $minimum_required['mem_limit']['required'] . '</span>';
                        $collapse_class = 'danger active';
                    }
                    else if ((float) $wp_mem_limit < $minimum_required['mem_limit']['recommended']) {
                        // warning
                        $wp_mem_limit_string = '<span class="ptsc_button ptsc_button_small ptsc_button_warning">' . $wp_mem_limit . '</span>';
                        $wp_mem_limit_string .= ' <span class="ptsc_text_warning">' . esc_html__( "Recommended Memory Limit is ", "ptsc" ) . $minimum_required['mem_limit']['recommended'] . '</span>';
                        if ($collapse_class != 'danger active') {
                            $collapse_class = 'warning active';
                        }
                    }



                    ?>
                    <div class="ptsc_collapse ptsc_collapse_<?php echo $collapse_class?> ptsc_margin_bottom_30">
                        <div class="ptsc_collapse_toggle">
                            <i class="ptsc_icon_down-open"></i>
                            <span>WordPress info</span>
                        </div>
                        <div class="ptsc_collapse_content">
                            <ul class="ptsc_list ptsc_list_padded ptsc_list_bordered">
                                <li class="ptsc_row">
                                    <div class="ptsc_col_sm_5"><?php echo esc_html_x( 'Site URL:', 'admin', 'ptsc') ?></div>
                                    <div class="ptsc_col_sm_7"><?php echo site_url(); ?></div>
                                </li>
                                <li class="ptsc_row">
                                    <div class="ptsc_col_sm_5"><?php echo esc_html_x( 'Home URL:', 'admin', 'ptsc') ?></div>
                                    <div class="ptsc_col_sm_7"><?php echo home_url(); ?></div>
                                </li>
                                <li class="ptsc_row">
                                    <div class="ptsc_col_sm_5"><?php echo esc_html_x( 'WordPress Version:', 'admin', 'ptsc') ?></div>
                                    <div class="ptsc_col_sm_7"><?php echo $wp_version_string; ?></div>
                                </li>
                                <li class="ptsc_row">
                                    <div class="ptsc_col_sm_5"><?php echo esc_html_x( 'WordPress Multi site:', 'admin', 'ptsc') ?></div>
                                    <div class="ptsc_col_sm_7"><?php echo $multi_site_string; ?></div>
                                </li>
                                <li class="ptsc_row">
                                    <div class="ptsc_col_sm_5"><?php echo esc_html_x( 'WordPress Debug Mode:', 'admin', 'ptsc') ?></div>
                                    <div class="ptsc_col_sm_7"><?php echo $debug_mode; ?></div>
                                </li>
                                <li class="ptsc_row">
                                    <div class="ptsc_col_sm_5"><?php echo esc_html_x( 'Max Upload Size:', 'admin', 'ptsc') ?></div>
                                    <div class="ptsc_col_sm_7"><?php echo $max_upload_size; ?></div>
                                </li>
                                <li class="ptsc_row">
                                    <div class="ptsc_col_sm_5"><?php echo esc_html_x( 'Memory Limit WP:', 'admin', 'ptsc') ?></div>
                                    <div class="ptsc_col_sm_7"><?php echo $wp_mem_limit_string; ?></div>
                                </li>
                            </ul>
                        </div>
                    </div>
                </div>

                <div class="ptsc_debug_section ptsc_debug_section_plugins">
                    <?php
                    $collapse_class = 'success';
                    $active_plugins = (array) get_option( 'active_plugins', array() );
                    if ( is_multisite() ) {
                        $active_plugins = array_merge( $active_plugins, get_site_option( 'active_sitewide_plugins', array() ) );
                    }
                    ?>
                    <div class="ptsc_collapse ptsc_collapse_<?php echo $collapse_class?> ptsc_margin_bottom_30">
                        <div class="ptsc_collapse_toggle">
                            <i class="ptsc_icon_down-open"></i>
                            <span>Plugins</span>
                        </div>
                        <div class="ptsc_collapse_content">
                            <ul class="ptsc_list ptsc_list_padded ptsc_list_bordered">
                                <li class="ptsc_row">
                                    <div class="ptsc_col_sm_5"><?php echo esc_html_x('WordPress Active Plugins:', 'admin', 'ptsc') ?></div>
                                    <div class="ptsc_col_sm_7"><?php echo count( $active_plugins ) ?></div>
                                </li>
                                <?php if ( count( $active_plugins ) > 0 ) { ?>
                                    <li class="ptsc_row">
                                        <div class="ptsc_col_sm_5"><?php echo esc_html_x( 'Active Plugins List:', 'admin', 'ptsc') ?></div>
                                        <div class="ptsc_col_sm_7">
                                            <ol>
                                                <?php foreach ( $active_plugins as $plugin ) {
                                                    $plugin_data    = @get_plugin_data( WP_PLUGIN_DIR . '/' . $plugin );
                                                    $dirname        = dirname( $plugin );
                                                    $version_string = '';
                                                    if ( ! empty( $plugin_data['Name'] ) ) {
                                                        // link the plugin name to the plugin url if available
                                                        echo '<li class="">';
                                                        $plugin_name = $plugin_data['Name'];
                                                        if ( ! empty( $plugin_data['PluginURI'] ) ) {
                                                            $plugin_name = "" . $plugin_name;
                                                        }
                                                        echo $plugin_name . ' by ' . strip_tags( $plugin_data['Author'] ) . ' version ' . $plugin_data['Version'] . $version_string;
                                                        echo "</li>";
                                                    } ?>
                                                <?php } ?>
                                            </ol>
                                        </div>
                                    </li>
                                <?php } ?>
                            </ul>
                        </div>
                    </div>
                </div>
                <div class="ptsc_debug_section ptsc_debug_section_theme">
                    <?php
                    $collapse_class = 'success';
                    global $wpdb;
                    ?>
                    <div class="ptsc_collapse ptsc_collapse_<?php echo $collapse_class?> ptsc_margin_bottom_30">
                        <div class="ptsc_collapse_toggle">
                            <i class="ptsc_icon_down-open"></i>
                            <span>Theme</span>
                        </div>
                        <div class="ptsc_collapse_content">
                            <ul class="ptsc_list ptsc_list_padded ptsc_list_bordered">
                                <li class="ptsc_row">
                                    <div class="ptsc_col_sm_5"><?php echo esc_html_x('Theme Name:', 'admin', 'ptsc') ?></div>
                                    <div class="ptsc_col_sm_7"><?php echo wp_get_theme()->Name; ?></div>
                                </li>
                                <li class="ptsc_row">
                                    <div class="ptsc_col_sm_5"><?php echo esc_html_x('Theme Author URL:', 'admin', 'ptsc') ?></div>
                                    <div class="ptsc_col_sm_7"><?php echo wp_get_theme()->{'Author URI'}; ?></div>
                                </li>
                                <li class="ptsc_row">
                                    <div class="ptsc_col_sm_5"><?php echo esc_html_x('Is Child Theme:', 'admin', 'ptsc') ?></div>
                                    <div class="ptsc_col_sm_7"><?php echo is_child_theme() ? 'Yes' : 'No'; ?></div>
                                </li>
                                <?php if ( is_child_theme() ) { ?>
                                    <li class="ptsc_row">
                                        <div class="ptsc_col_sm_5"><?php echo esc_html_x('Parent Theme Name:', 'admin', 'ptsc') ?></div>
                                        <div class="ptsc_col_sm_7"><?php echo wp_get_theme( $active_theme->Template )->Name; ?></div>
                                    </li>
                                    <li class="ptsc_row">
                                        <div class="ptsc_col_sm_5"><?php echo esc_html_x('Parent Theme Version:', 'admin', 'ptsc') ?></div>
                                        <div class="ptsc_col_sm_7"><?php echo wp_get_theme( $active_theme->Template )->Version; ?></div>
                                    </li>
                                    <li class="ptsc_row">
                                        <div class="ptsc_col_sm_5"><?php echo esc_html_x('Parent Theme Author URL:', 'admin', 'ptsc') ?></div>
                                        <div class="ptsc_col_sm_7"><?php echo wp_get_theme( $active_theme->Template )->{'Author URI'}; ?></div>
                                    </li>
                                <?php } ?>


                            </ul>
                        </div>
                    </div>
                </div>
                <div class="ptsc_debug_section ptsc_debug_section_server">
                    <?php
                    $collapse_class = 'success';

                    // PHP memory limit
                    $php_mem_limit = ini_get("memory_limit");
                    $php_mem_limit_string = '<span class="ptsc_button ptsc_button_small ptsc_button_success">' . $php_mem_limit . '</span>';
                    if ((float) $php_mem_limit < $minimum_required['mem_limit']['required']) {
                        // success
                        $php_mem_limit_string = '<span class="ptsc_button ptsc_button_small ptsc_button_danger">' . $php_mem_limit . '</span>';
                        $php_mem_limit_string .= ' <span class="ptsc_text_danger">' . esc_html__( "Minimum Memory limit is ", "ptsc" ) . $minimum_required['mem_limit']['required'] . '</span>';
                        $collapse_class = 'danger active';
                    }
                    else if ((float) $php_mem_limit < $minimum_required['mem_limit']['recommended']) {
                        // warning
                        $php_mem_limit_string = '<span class="ptsc_button ptsc_button_small ptsc_button_warning">' . $php_mem_limit . '</span>';
                        $php_mem_limit_string .= ' <span class="ptsc_text_warning">' . esc_html__( "Recommended Memory Limit is ", "ptsc" ) . $minimum_required['mem_limit']['recommended'] . '</span>';
                        if ($collapse_class != 'danger active') {
                            $collapse_class = 'warning active';
                        }
                    }

                    // PHP version
                    $php_version = phpversion();
                    $php_version_text = '<span class="ptsc_button ptsc_button_small ptsc_button_success">' . $php_version . '</span>';
                    if (version_compare($php_version, $minimum_required['version_php']['required'], 'lt')) {
                        // danger
                        $php_version_text = '<span class="ptsc_button ptsc_button_small ptsc_button_danger">' . $php_version . '</span>';
                        $php_version_text .= ' <span class="ptsc_text_danger">' . esc_html__( "Minimum Required PHP version is ", "ptsc" ) . $minimum_required['version_php']['required'] . '</span>';
                        $collapse_class = 'danger active';
                    }
                    else if (version_compare($php_version, $minimum_required['version_php']['recommended'], 'lt')) {
                        // warning
                        $php_version_text = '<span class="ptsc_button ptsc_button_small ptsc_button_warning">' . $php_version . '</span>';
                        $php_version_text .= ' <span class="ptsc_text_warning">' . esc_html__( "Recommended is above ", "ptsc" ) . $minimum_required['version_php']['recommended'] . '</span>';
                        if ($collapse_class != 'danger active') {
                            $collapse_class = 'warning active';
                        }
                    }


                    ?>
                    <div class="ptsc_collapse ptsc_collapse_<?php echo $collapse_class?> ptsc_margin_bottom_30">
                        <div class="ptsc_collapse_toggle">
                            <i class="ptsc_icon_down-open"></i>
                            <span>Server info</span>
                        </div>
                        <div class="ptsc_collapse_content">
                            <ul class="ptsc_list ptsc_list_padded ptsc_list_bordered">
                                <li class="ptsc_row">
                                    <div class="ptsc_col_sm_5"><?php echo esc_html_x('PHP Version:', 'admin', 'ptsc') ?></div>
                                    <div class="ptsc_col_sm_7"><?php echo $php_version_text; ?></div>
                                </li>
                                <li class="ptsc_row">
                                    <div class="ptsc_col_sm_5"><?php echo esc_html_x('Memory Limit PHP:', 'admin', 'ptsc') ?></div>
                                    <div class="ptsc_col_sm_7"><?php echo $php_mem_limit_string; ?></div>
                                </li>
                                <li class="ptsc_row">
                                    <div class="ptsc_col_sm_5"><?php echo esc_html_x('PHP Safe Mode:', 'admin', 'ptsc') ?></div>
                                    <div class="ptsc_col_sm_7"><?php echo ( ini_get( 'safe_mode' ) ) ? esc_html__( 'ON', "ptsc" ) : esc_html__( 'OFF', "ptsc" ); ?></div>
                                </li>
                                <li class="ptsc_row">
                                    <div class="ptsc_col_sm_5"><?php echo esc_html_x('PHP Time Execution:', 'admin', 'ptsc') ?></div>
                                    <div class="ptsc_col_sm_7"><?php echo ini_get( 'max_execution_time' ); ?> Seconds <?php ?></div>
                                </li>
                                <li class="ptsc_row">
                                    <div class="ptsc_col_sm_5"><?php echo esc_html_x('PHP Temporary Directory:', 'admin', 'ptsc') ?></div>
                                    <div class="ptsc_col_sm_7"><?php echo sys_get_temp_dir() ?></div>
                                </li>
                                <li class="ptsc_row">
                                    <div class="ptsc_col_sm_5"><?php echo esc_html_x('MySQL Version:', 'admin', 'ptsc') ?></div>
                                    <div class="ptsc_col_sm_7"><?php echo $wpdb->get_var( "SELECT VERSION()" ); ?></div>
                                </li>
                                <li class="ptsc_row">
                                    <div class="ptsc_col_sm_5"><?php echo esc_html_x('Server Software:', 'admin', 'ptsc') ?></div>
                                    <div class="ptsc_col_sm_7"><?php echo esc_html( @$_SERVER['SERVER_SOFTWARE'] ); ?></div>
                                </li>
                                <li class="ptsc_row">
                                    <div class="ptsc_col_sm_5"><?php echo esc_html_x('MySQLi Extension:', 'admin', 'ptsc') ?></div>
                                    <div class="ptsc_col_sm_7"><?php echo function_exists( 'mysqli_connect' ) ? esc_html__( "Installed", "ptsc" ) : esc_html__( "Not Installed", "ptsc" ); ?></div>
                                </li>
                            </ul>
                        </div>
                    </div>
                </div>
                <div class="ptsc_debug_section ptsc_debug_section_curl">
                    <?php
                    $collapse_class = 'success';

                    // Multi site
                    $curl_installed = (function_exists( 'curl_version' )) ? esc_html__( 'Installed', "ptsc" ) : esc_html__( 'Not Installed', "ptsc" );
                    $curl_installed_string = '<span class="ptsc_button ptsc_button_small ptsc_button_success">' . $curl_installed . '</span>';
                    if ($curl_installed == 'Not Installed') {
                        // success
                        $curl_installed_string = '<span class="ptsc_button ptsc_button_small ptsc_button_danger">' . $curl_installed . '</span>';
                        $curl_installed_string .= ' <span class="ptsc_text_danger">' . esc_html__( "cURL is required but not installed, ", "ptsc" ) . '</span>';
                        $collapse_class = 'danger active';
                    }




                    // CURL google with http
                    if ( ! function_exists( 'curl_version' ) ) {
                        $curl_google = esc_html__('cURL not Installed', "ptsc" );
                    }
                    else {
                        $ch = curl_init();
                        curl_setopt( $ch, CURLOPT_URL, "http://www.google.com" );
                        curl_setopt( $ch, CURLOPT_RETURNTRANSFER, true );
                        $result = curl_exec( $ch );
                        if ( $result === false ) {
                            $curl_google = '<span class="ptsc_button ptsc_button_small ptsc_button_danger">' . esc_html__('Failed', "ptsc" ) . '</span>';
                            if ( $errno = curl_errno( $ch ) ) {
                                $error_message = curl_error( $ch );
                                $curl_google .= ' <span class="ptsc_text_danger">'. $error_message . '</span>';
                            }
                            $collapse_class = 'danger active';
                        }
                        else {
                            $curl_google = '<span class="ptsc_button ptsc_button_small ptsc_button_success">' . esc_html__('Passed', "ptsc" ) . '</span>';
                        }
                    }

                    // CURL google with https
                    if ( ! function_exists( 'curl_version' ) ) {
                        $curl_google_https = esc_html__('cURL not Installed', "ptsc" );
                    }
                    else {
                        $ch = curl_init();
                        curl_setopt( $ch, CURLOPT_URL, "https://www.google.com" );
                        curl_setopt( $ch, CURLOPT_RETURNTRANSFER, true );
                        curl_setopt( $ch, CURLOPT_SSL_VERIFYHOST, 0 );
                        if (get_option('ptsc_curl_ssl_verify', '') == 'yes') {
                            curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, true);
                        }
                        else {
                            curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
                        }
                        $result = curl_exec( $ch );
                        if ( $result === false ) {
                            $curl_google_https = '<span class="ptsc_button ptsc_button_small ptsc_button_danger">' . esc_html__('Failed', "ptsc" ) . '</span>';
                            if ( $errno = curl_errno( $ch ) ) {
                                $error_message = curl_error( $ch );
                                $curl_google_https .= ' <span class="ptsc_text_danger">'. $error_message . '</span>';
                            }
                            $collapse_class = 'danger active';
                        }
                        else {
                            $curl_google_https = '<span class="ptsc_button ptsc_button_small ptsc_button_success">' . esc_html__('Passed', "ptsc" ) . '</span>';
                        }
                    }

                    ?>
                    <div class="ptsc_collapse ptsc_collapse_<?php echo $collapse_class?> ptsc_margin_bottom_30">
                        <div class="ptsc_collapse_toggle">
                            <i class="ptsc_icon_down-open"></i>
                            <span>cURL Extension info</span>
                        </div>
                        <div class="ptsc_collapse_content">
                            <ul class="ptsc_list ptsc_list_padded ptsc_list_bordered">
                                <li class="ptsc_row">
                                    <div class="ptsc_col_sm_5"><?php echo esc_html_x('cURL Extension:', 'admin', 'ptsc') ?></div>
                                    <div class="ptsc_col_sm_7"><?php echo $curl_installed_string; ?></div>
                                </li>
                                <li class="ptsc_row">
                                    <div class="ptsc_col_sm_5"><?php echo esc_html_x( 'cURL Test with google.com:', 'admin', 'ptsc') ?></div>
                                    <div class="ptsc_col_sm_7"><?php echo $curl_google?></div>
                                </li>
                                <li class="ptsc_row">
                                    <div class="ptsc_col_sm_5"><?php echo esc_html_x('cURL Test with port 443 and google.com:', 'admin', 'ptsc') ?></div>
                                    <div class="ptsc_col_sm_7"><?php echo $curl_google_https?></div>
                                </li>
                            </ul>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
