<?php


abstract class PTSC_DB {

	public $table_name;
	public $primary_key;

	function __construct() {
	}


	public function ptsc_get_columns() {
	    return array();

	}

	public function ptsc_get_column_defaults() {
		return array();
	}

	//Get the row using primary key
	public function ptsc_get( $id ) {
		global $wpdb;

		$id = absint( $id );

		$result = $wpdb->get_row( $wpdb->prepare( "SELECT * FROM `$this->table_name` WHERE `$this->primary_key`= %s LIMIT 1;", $id ),ARRAY_A );
		if ( $wpdb->last_error ) {
			return $wpdb->last_error;
		}
		return $result;
	}

	public function ptsc_get_by( $column, $value ) {
		global $wpdb;

		$column = esc_sql( $column );

		$result = $wpdb->get_results( $wpdb->prepare( "SELECT * FROM `$this->table_name` WHERE `$column`= %s;", $value ),ARRAY_A );

		if ( $wpdb->last_error ) {
			$wpdb->last_error;
		}

		return $result;
	}


	public function ptsc_get_sorted_by ($column, $value, $order_column) {
		global $wpdb;
		$result = $wpdb->get_results($wpdb->prepare("SELECT * FROM `$this->table_name` WHERE `$column` = %s ORDER BY `$order_column`",$value),ARRAY_A);
		if($wpdb->last_error) {
			return $wpdb->last_error;
		}
		return $result;
	}

	public function ptsc_get_column( $column, $id ) {
		global $wpdb;
		$column = esc_sql( $column );

		$result = $wpdb->get_var( $wpdb->prepare( "SELECT `$column` FROM $this->table_name WHERE `$this->primary_key` = %s LIMIT 1;", $id ) );

		if ( $wpdb->last_error ) {
			return $wpdb->last_error;
		}

		return $result;
	}

	public function ptsc_get_column_by( $column, $column_where, $column_value ) {
		global $wpdb;

		$column_where = esc_sql( $column_where );
		$column       = esc_sql( $column );

		return $wpdb->get_var( $wpdb->prepare( "SELECT `$column` FROM `$this->table_name` WHERE `$column_where` = %s LIMIT 1;", $column_value ) );
	}

	function ptsc_add( $data, $type = '' ) {
		global $wpdb;
		//Set default values
		$data = wp_parse_args( $data, $this->ptsc_get_column_defaults() );

		do_action( "ptsc_pre_insert_" . $type, $data );


		//~~ returns empty array to hold columns
		$column_formats = $this->ptsc_get_columns();

		$data     = array_change_key_case( $data );

		$data     = array_intersect_key( $data, $column_formats );


		$data_key = array_keys( $data );


		$column_formats = array_merge( array_flip( $data_key ), $column_formats );

		$wpdb->insert( $this->table_name, $data, $column_formats );
		do_action( "ptsc_post_insert_" . $type, $data );
		$wpdb_insert_id = $wpdb->insert_id;

		if ( $wpdb_insert_id == 0 ) {
			return $wpdb->last_error;
		}

		return $wpdb_insert_id;
	}

	function ptsc_delete( $id = 0 ) {
		global $wpdb;
		$id = absint( $id );
		if ( empty( $id ) ) {
			return false;
		}

		if ( false === $wpdb->query( $wpdb->prepare( "DELETE FROM `$this->table_name` WHERE `$this->primary_key` = %s", $id ) ) ) {
			if ( $wpdb->last_error ) {
				return $wpdb->last_error;
			}
		}

		return true;
	}

    function ptsc_delete_all( ) {
        global $wpdb;

        if ( false === $wpdb->query( "DELETE FROM `$this->table_name`" ) ) {
            if ( $wpdb->last_error ) {
                return $wpdb->last_error;
            }
        }

        return true;
    }

	function ptsc_delete_on( $column, $value ) {
		global $wpdb;

		if ( false === $wpdb->query( $wpdb->prepare( "DELETE FROM `$this->table_name` WHERE `$column` = %s", $value ) ) ) {

			if ( $wpdb->last_error ) {
				return $wpdb->last_error;
			} else {
				return false;
			}

		}

		return true;
	}

	function ptsc_select() {
		global $wpdb;
		$result = $wpdb->get_results( "SELECT * FROM `$this->table_name`", ARRAY_A );

		return $result;
	}

	function ptsc_select_distinct($distinct_column){
        global $wpdb;
        $result = $wpdb->get_results( "SELECT DISTINCT ($distinct_column) FROM `$this->table_name`", ARRAY_A );

        return $result;
    }
    function ptsc_select_table() {
        global $wpdb;
        $result_table = $wpdb->get_results( "SELECT * FROM `$this->table_name` WHERE table_flag=1 ", ARRAY_A );

        return $result_table;
    }
    function ptsc_select_group() {
        global $wpdb;
        $result_group = $wpdb->get_results( "SELECT * FROM `$this->table_name` WHERE table_flag=0 ", ARRAY_A );

        return $result_group;
    }

	function ptsc_count_elements() {
		global $wpdb;
		$result = $wpdb->get_results("SELECT COUNT(*) FROM `$this->table_name`",ARRAY_A);
		return $result;
	}

	function ptsc_count_elements_by ($column,$value) {
		global $wpdb;
		$result = $wpdb->get_results($wpdb->prepare("SELECT * FROM `$this->table_name` WHERE `$column`= %s",$value),ARRAY_A);
		return count($result);
	}


	//~~  Update Row
	public function ptsc_update( $row_id, $data = array(), $where = '' ) {
		global $wpdb;
		// Row ID must be positive integer
		$row_id = absint( $row_id );
		if( empty( $row_id ) ) {
			return false;
		}
		if( empty( $where ) ) {
			$where = $this->primary_key;
		}

		// Initialise column format array
		$column_formats = $this->ptsc_get_columns();
        //todo: remove lateron
        $column_formats["rows_table"]="%d";
        $column_formats["rows_single_table"]="%d";

		// Force fields to lower case
		$data = array_change_key_case( $data );
		// White list columns
		$data = array_intersect_key( $data, $column_formats );
		// Reorder $column_formats to match the order of columns given in $data
		$data_keys = array_keys( $data );
		$column_formats = array_merge( array_flip( $data_keys ), $column_formats );

		if ( false === $wpdb->update( $this->table_name, $data, array( $where => $row_id ), $column_formats ) ) {
			return false;
		}
		return true;
	}

    public function ptsc_update_specific_column( $row_id,$column_name = '', $data = '', $where = '' ) {
        global $wpdb;
        // Row ID must be positive integer
        $row_id = absint( $row_id );
        if( empty( $row_id ) ) {
            return false;
        }
        if( empty( $where ) ) {
            $where = $this->primary_key;
        }

        // Initialise column format array
        $column_formats = $this->ptsc_get_columns();
        //todo: remove lateron
        $column_formats["rows_table"]="%d";
        $column_formats["rows_single_table"]="%d";

        // Force fields t o lower case
        $data = array_change_key_case( $data );
        // White list columns
        $data = array_intersect_key( $data, $column_formats );
        // Reorder $column_formats to match the order of columns given in $data
        $data_keys = array_keys( $data );
        $column_formats = array_merge( array_flip( $data_keys ), $column_formats );

        if ( false === $wpdb->update( $this->table_name, $data, array( $where => $row_id ), $column_formats ) ) {
            return false;
        }
        return true;
    }

	function ptsc_update_on( $data = array(), $where =array() ) {
		global $wpdb;
		if ( empty ( $where ) ) {
			$where = $this->primary_key;
		}

		//Initialize the column formats
		$column_formats = $this->ptsc_get_columns();

		//Force fields to be in lower case
		$data = array_change_key_case( $data );

		//Whitelist the column format

		$data = array_intersect_key( $data, $column_formats );

		//Get array keys

		$array_keys = array_keys( $data );

		//Reorder the column formats to match with $data

		$column_formats = array_merge( array_flip( $array_keys ), $column_formats );

		//Run the query

		if ( false === $wpdb->update( $this->table_name,$data,$where, $column_formats ) ) {
			return false;
		}
		return true;
	}

	function ptsc_table_exists( $table ) {
		global $wpdb;

		$table = sanitize_text_field( $table );

		return $wpdb->get_var( $wpdb->prepare( "SHOW TABLES LIKE '%s'", $table ) ) === $table;
	}

	function ptsc_table_installed() {
		return $this->ptsc_table_exists( $this->table_name );
	}

    function ptsc_delete_tooltip( $tooltip_id ) {
        global $wpdb;
        $Q = "DELETE FROM `" . ptsc_get_tooltips_table_name() . "` WHERE `tooltip_id`='$tooltip_id'";
        $wpdb->query( $Q );
    }


}